==> nextcloud-31.0.11.tgz: nextcloud/apps/twofactor_totp/l10n/sr.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Укључили сте TOTP двофакторску проверу идентитета за Ваш налог",
    "You disabled TOTP two-factor authentication for your account" : "Искључили сте TOTP двофакторску проверу идентитета за Ваш налог",
    "TOTP two-factor authentication disabled by the administration" : "Администратор је искључио TOTP двофакторску проверу идентитета",
    "TOTP (Authenticator app)" : "TOTP (апликација за проверу идентитета)",
    "Authenticate with a TOTP app" : "Идентификујте се са TOTP апликацијом",
    "Two-Factor TOTP Provider" : "Провајдер двофакторске TOTP",
    "Two-factor TOTP provider" : "Пружалац услуге двофакторске TOTP",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Пружалац двофакторске провере идентитета за TOTP (RFC 6238)",
    "Could not enable TOTP" : "Не могу да укључим TOTP",
    "Could not verify your key. Please try again" : "Не могу да верификујем Ваш кључ. Пробајте поново",
    "Enable TOTP" : "Укључи TOTP",
    "Your new TOTP secret is:" : "Ово је Ваша нова TOTP тајна:",
    "For quick setup, scan this QR code with your TOTP app:" : "За брзо подешавање, скенирајте овај QR код са Вашом TOTP апликацијом",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Када сте подесили апликацију, унесите пробни код испод да проверите да ли све ради како треба:",
    "Authentication code" : "Код за проверу идентитета",
    "Verify" : "Провери",
    "Get the authentication code from the two-factor authentication app on your device." : "Узмите идентификациони код из апликације за проверу идентитета са Вашег уређаја.",
    "Submit" : "Пошаљи"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-32.0.0p0.tgz: nextcloud/apps/twofactor_totp/l10n/sr.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Укључили сте TOTP двофакторску проверу идентитета за Ваш налог",
    "You disabled TOTP two-factor authentication for your account" : "Искључили сте TOTP двофакторску проверу идентитета за Ваш налог",
    "TOTP two-factor authentication disabled by the administration" : "Администратор је искључио TOTP двофакторску проверу идентитета",
    "TOTP (Authenticator app)" : "TOTP (апликација за проверу идентитета)",
    "Authenticate with a TOTP app" : "Идентификујте се са TOTP апликацијом",
    "Two-Factor TOTP Provider" : "Провајдер двофакторске TOTP",
    "Two-factor TOTP provider" : "Пружалац услуге двофакторске TOTP",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Пружалац двофакторске провере идентитета за TOTP (RFC 6238)",
    "Could not enable TOTP" : "Не могу да укључим TOTP",
    "Could not verify your key. Please try again" : "Не могу да верификујем Ваш кључ. Пробајте поново",
    "Enable TOTP" : "Укључи TOTP",
    "Your new TOTP secret is:" : "Ово је Ваша нова TOTP тајна:",
    "For quick setup, scan this QR code with your TOTP app:" : "За брзо подешавање, скенирајте овај QR код са Вашом TOTP апликацијом",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Када сте подесили апликацију, унесите пробни код испод да проверите да ли све ради како треба:",
    "Authentication code" : "Код за проверу идентитета",
    "Verify" : "Провери",
    "Get the authentication code from the two-factor authentication app on your device." : "Узмите идентификациони код из апликације за проверу идентитета са Вашег уређаја.",
    "Submit" : "Пошаљи",
    "TOTP two-factor authentication disabled by an admin" : "Администратор искључио TOTP двофакторску проверу идентитета",
    "TOTP two-factor provider" : "Двофакторски провајдер за TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Провајдер двофакторске TOTP (RFC 6238)"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
